@@ -1,7 +1,6 @@
 import io
 import os
 import abc
-import threading
 import re
 
 class Template(object):
@@ -162,7 +161,6 @@ class Template(object):
 			import string
 			tmpl = string.Template(source)
 			code = tmpl.safe_substitute(local_vars)
-			print code
 			return eval(code,local_vars or {},self)
 
 		return compiled_function
